@@ -3,8 +3,8 @@ import pandas as pd
 import re
 
 from typing import List
-from pydriller.git_repository import GitRepository
-from pydriller.repository_mining import RepositoryMining
+from pydriller.git import Git
+from pydriller.repository import Repository
 from pydriller.metrics.process.change_set import ChangeSet
 from pydriller.metrics.process.code_churn import CodeChurn
 from pydriller.metrics.process.commits_count import CommitsCount
@@ -17,8 +17,6 @@ from repominer.files import FailureProneFile
 
 from typing import Any, Dict, Set, Union
 
-full_name_pattern = re.compile(r'git(hub|lab)\.com/([\w\W]+)$')
-
 
 def get_content(path: str) -> Union[str, None]:
     """ Get the content of a file as plain text.
@@ -67,21 +65,21 @@ class BaseMetricsExtractor:
 
     """
 
-    def __init__(self, path_to_repo: str, at: str = 'release', clone_repo_to: str = None):
+    def __init__(self, path_to_repo: str, clone_repo_to: str = None, at: str = 'release'):
         """ The class constructor.
 
         Parameters
         ----------
         path_to_repo : str
-            The path to the repository.
+            The path to a local or remote repository.
+
+        clone_repo_to : str
+            Path to clone the repository to.
+            If path_to_repo links to a local repository, this parameter is not used. Otherwise it is mandatory.
 
         at : str
             When to extract metrics: at each release or each commit.
 
-        clone_repo_to : str
-            Path to clone the repository to. If None is passed, it is taken from the environment
-            variable TMP_REPOSITORIES_DIR
-
         Attributes
         ----------
         dataset: pandas.DataFrame
@@ -90,42 +88,41 @@ class BaseMetricsExtractor:
         Raises
         ------
         ValueError
-            If `at` is not one of the following: release, commit.
+            If `at` is not release or commit, or if the path to the remote repository does not link to a github or
+            gitlab repository.
         NotImplementedError
             The commit option is not implemented yet.
 
         """
 
         if at not in ('release', 'commit'):
-            raise ValueError(f'{at} is not valid! Try with \'release\' or \'commit\'.')
+            raise ValueError(f'{at} is not valid! Use \'release\' or \'commit\'.')
 
-        if at == 'commit':
-            raise NotImplementedError('This functionality is not implemented yet! Please, use at=release')
+        self.path_to_repo = path_to_repo
 
-        if os.path.isdir(path_to_repo):
-            self.path_to_repo = path_to_repo
-            self.repo_miner = RepositoryMining(path_to_repo=path_to_repo,
-                                               only_releases=True if at == 'release' else False,
-                                               order='date-order')
-        elif is_remote(path_to_repo):
-            match = full_name_pattern.search(path_to_repo.replace('.git', ''))
-            repo_name = match.groups()[1].split('/')[1]
+        if is_remote(path_to_repo):
 
             if not clone_repo_to:
-                clone_repo_to = os.getenv('TMP_REPOSITORIES_DIR')
+                raise ValueError('clone_repo_to is mandatory when linking to a remote repository.')
 
-            path_to_clone = os.path.join(clone_repo_to, repo_name)
-            self.path_to_repo = path_to_clone
+            full_name_pattern = re.compile(r'git(hub|lab)\.com/([\w\W]+)$')
+            match = full_name_pattern.search(path_to_repo.replace('.git', ''))
 
-            self.repo_miner = RepositoryMining(path_to_repo=path_to_repo,
-                                               clone_repo_to=clone_repo_to if not os.path.isdir(path_to_clone) else None,
-                                               only_releases=True if at == 'release' else False,
-                                               order='date-order')
+            if not match:
+                raise ValueError('The remote repository must be hosted on github or gitlab.')
 
-        else:
-            raise ValueError(f'{path_to_repo} does not seem a path or url to a Git repository.')
+            repo_name = match.groups()[1].split('/')[1]
+            self.path_to_repo = os.path.join(clone_repo_to, repo_name)
 
-        self.releases = [commit.hash for commit in self.repo_miner.traverse_commits()]
+            if os.path.isdir(self.path_to_repo):
+                clone_repo_to = None
+
+        repo_miner = Repository(path_to_repo=path_to_repo,
+                                clone_repo_to=clone_repo_to,
+                                only_releases=True if at == 'release' else False,
+                                order='date-order', num_workers=1)
+
+        self.commits_at = [commit.hash for commit in repo_miner.traverse_commits()]
         self.dataset = pd.DataFrame()
 
     def get_files(self) -> Set[str]:
@@ -167,7 +164,7 @@ class BaseMetricsExtractor:
             A dictionary of <metric, value>.
 
         """
-        return dict()
+        return {}
 
     def get_process_metrics(self, from_commit: str, to_commit: str) -> dict:
         """ Extract process metrics for an evolution period.
@@ -181,7 +178,7 @@ class BaseMetricsExtractor:
 
         """
         change_set = ChangeSet(self.path_to_repo, from_commit=from_commit, to_commit=to_commit)
-        code_churn = CodeChurn(self.path_to_repo, from_commit=from_commit, to_commit=to_commit)
+        code_churn = CodeChurn(self.path_to_repo, from_commit=from_commit, to_commit=to_commit, ignore_added_files=True)
         commits_count = CommitsCount(self.path_to_repo, from_commit=from_commit, to_commit=to_commit)
         contributors_count = ContributorsCount(self.path_to_repo, from_commit=from_commit, to_commit=to_commit)
         highest_contributors_experience = ContributorsExperience(self.path_to_repo, from_commit=from_commit,
@@ -223,17 +220,18 @@ class BaseMetricsExtractor:
         process: bool
             Whether to extract process metrics.
         delta: bool
-            Whether to extract delta metrics between two successive releases (or commits).
+            Whether to extract delta metrics between two successive releases or commits.
 
         """
-        git_repo = GitRepository(self.path_to_repo)
+        self.dataset = pd.DataFrame()
+        git_repo = Git(self.path_to_repo)
 
         metrics_previous_release = dict()  # Values for iac metrics in the last release
 
-        for commit in RepositoryMining(self.path_to_repo, order='date-order').traverse_commits():
+        for commit in Repository(self.path_to_repo, order='date-order', num_workers=1).traverse_commits():
 
             # To handle renaming in metrics_previous_release
-            for modified_file in commit.modifications:
+            for modified_file in commit.modified_files:
 
                 old_path = modified_file.old_path
                 new_path = modified_file.new_path
@@ -242,7 +240,7 @@ class BaseMetricsExtractor:
                     # Rename key old_path wit new_path
                     metrics_previous_release[new_path] = metrics_previous_release.pop(old_path)
 
-            if commit.hash not in self.releases:
+            if commit.hash not in self.commits_at:
                 continue
 
             # Else
@@ -251,9 +249,9 @@ class BaseMetricsExtractor:
 
             if process:
                 # Extract process metrics
-                i = self.releases.index(commit.hash)
-                from_previous_commit = commit.hash if i == 0 else self.releases[i - 1]
-                to_current_commit = commit.hash  # = self.releases[i]
+                i = self.commits_at.index(commit.hash)
+                from_previous_commit = commit.hash if i == 0 else self.commits_at[i - 1]
+                to_current_commit = commit.hash  # = self.commits_at[i]
                 process_metrics = self.get_process_metrics(from_previous_commit, to_current_commit)
 
             for filepath in self.get_files():
