@@ -7,13 +7,28 @@ nlp = spacy.load("en_core_web_sm")
 
 def get_head_dependents(sentence: str) -> List[str]:
     """
-    Compute the syntactic dependencies and return a list of tuples (head, dependents)
+    Compute the syntactic dependencies and
+    return a list of tuples (head, dependents)
+
+    Parameters
+    ----------
+    sentence : str
+        The sentence to analyze
+
+    Return
+    ------
+    str
+        A list of tuples (head, dependents).
+
     """
     sentence = re.sub(r'\s+', ' ', sentence)
     doc = nlp(sentence)
     dep = [token.dep_ for token in doc]
 
-    compounds = [token for token in doc if token.dep_ == 'compound']  # Get list of compounds in doc
+    # Get list of compounds in doc
+    compounds = [token for token in doc if token.dep_ == 'compound']
+
+    # Identifies roots and direct objects
     for token in compounds:
         if token.head.dep_ == 'dobj':
             dep[token.i] = 'dobj'
@@ -25,8 +40,19 @@ def get_head_dependents(sentence: str) -> List[str]:
 
 def key_value_list(d):
     """
-    This function iterates over all the key-value pairs of a dictionary and returns a list of tuple (key, value).
-    d -- a dictionary to iterate through
+    This function iterates over all the key-value pairs of a dictionary and
+    returns a list of tuples (key, value).
+
+    Parameters
+    ----------
+    d : Union[dict, list]
+        The dictionary to iterate through
+
+    Return
+    ------
+    str
+        A list of tuples (key, value).
+
     """
     if not isinstance(d, dict) and not isinstance(d, list):
         return []
